Skip to main contentModule read
Source - ParseError
- ReadSane
- To be able read SANE-encoded data we need to be able convert the
Vec<u8> of little-endian
data to the corresponding vector of values
- read_sane
- Parse a SANE-encoded file into an array with known type and rank
- read_sane_arrays
- Parse multiple SANE-encoded arrays from a file
- read_sane_arrays_dyn
- Parse multiple SANE-encoded arrays each with dynamic data type and rank
- read_sane_dyn
- Parse a SANE-encoded file into an array with dynamic type and rank